/* d3.select is used to do DOM manipulation,
      	that is document object manipulation 
      */

import {select, arc} from 'd3'
const svg = select('svg');
svg.style('background-color', 'orange');

const height = +svg.attr('height'),
       width = +svg.attr('width');
/* 
	With one argument svg.attr gives you the value of that attr.
  + is the same thing as parseFloat
*/

// append is used by d3 to add things
//   to the dom element
const circle = svg.append('circle');
// set the radius attribute to 200
// 960 is the screen width
circle
	.attr('r', height / 2)
  .attr('cx', width / 2)
	.attr('cy', height / 2)
	.attr('fill', 'yellow')
	.attr('stroke', 'black')
	.attr('stroke-width', 2)
;

const eyeSpacing = 100;
const eyeYOffset = -20;
const eyeRadius = 9;
const eyebrowWidth = 50;
const eyebrowHeight = 15;


const g = svg.append('g')
	.attr('transform', `translate(${width / 2}, ${height / 2})`)

const eyesG = g.append('g')
	.attr('stroke', 'black')
	.attr('stroke-width', 5)

const leftEye = eyesG.append('circle')
	.attr('fill', 'white')
	.attr('r', eyeRadius)
  .attr('cx',-eyeSpacing*0.9)
	.attr('cy',eyeYOffset);

const rightEye = eyesG.append('circle')
	.attr('fill', 'white')
	.attr('r', eyeRadius)
  .attr('cx', eyeSpacing)
	.attr('cy', eyeYOffset+5);

const leftEyebrow = eyesG.append('rect')
	.attr('width', eyebrowWidth)
	.attr('height', eyebrowHeight)
	.attr('x', -eyeSpacing - eyebrowWidth / 2)
	.attr('y', eyeYOffset*3);

const rightEyebrow = eyesG.append('rect')
	.attr('width', eyebrowWidth)
	.attr('height', eyebrowHeight)
	.attr('x', eyeSpacing - eyebrowWidth / 2)
	.attr('y', eyeYOffset*3);


// arc() is an arc generator provided by e3
// append path to g rather than directly to svg
const mouth = g.append('path')
	.attr('d', arc()({
    	innerRadius: 150,
    	outerRadius: 170,
    	startAngle: Math.PI / 2,
    	endAngle: Math.PI * 3/2
  }))
	.attr('fillColor', 'white')



console.log(d3);
console.log(typeof width)